import logging
from aiogram import Bot, Dispatcher
from aiogram.client.default import DefaultBotProperties
from aiogram.enums import ParseMode
from aiogram.fsm.storage.memory import MemoryStorage
from aiogram.types import Message, KeyboardButton, ReplyKeyboardMarkup, InlineKeyboardMarkup, CallbackQuery, InlineKeyboardButton
from typing import Optional, Union
KeyboardType = Union[InlineKeyboardMarkup, ReplyKeyboardMarkup]

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)


def get_bot(API_TOKEN):
    """Создает объект БОТА"""
    bot = Bot(token=API_TOKEN, default=DefaultBotProperties(parse_mode=ParseMode.HTML))
    dp = Dispatcher(storage=MemoryStorage())
    return dp, bot

def create_menu(button_texts: list[str]):
    """Создает объект клавиатуры с кнопками
    На вход объект БОТА, Список названий кнопок"""
    buttons = [KeyboardButton(text=text) for text in button_texts]
    # группируем кнопки в строки (по одной кнопке на строку)
    keyboard = ReplyKeyboardMarkup(
        keyboard=[[button] for button in buttons],
        resize_keyboard=True
    )
    return keyboard

def create_inline_menu(buttons_info: list[dict]) -> InlineKeyboardMarkup:
    """
    Создает inline-клавиатуру.
    
    button_info: список словарей с параметрами кнопки, например:
        [{"text": "Нажми меня", "callback_data": "btn_1"},
         {"text": "Ссылка", "url": "https://example.com"}]
         
    Возвращает объект InlineKeyboardMarkup
    """
    buttons = []
    for info in buttons_info:
        button = InlineKeyboardButton(**info)  # передаем text, callback_data или url
        buttons.append([button])  # каждая кнопка в отдельной строке
    keyboard = InlineKeyboardMarkup(inline_keyboard=buttons)
    return keyboard


async def send_message_to_chat(
    chat_id: int,
    text: str,
    bot: Bot,
    reply_markup: Optional[KeyboardType] = None
):
    """
    Универсальная функция отправки сообщения.
    
    reply_markup: InlineKeyboardMarkup, ReplyKeyboardMarkup или None
    """
    await bot.send_message(
        chat_id=chat_id,
        text=text,
        reply_markup=reply_markup  # можно None
    )



# Обработчик нажатия кнопки
async def start_bot(dp, bot):
    await dp.start_polling(bot)






def install_django():
    """
django-admin startproject NAME
python django startapp APPNAME    
    """


def set_postgres():
    

    """pip install python-dotenv
--- docker-compose.yml

services:
  db:
    image: postgres:15
    container_name: postgres
    env_file:
      - .env
    ports:
      - "5432:5432"
    volumes:
      - postgres_data:/var/lib/postgresql/data
    restart: always

    

--- settings.py

from dotenv import load_dotenv
import os
# Загружаем .env
load_dotenv(BASE_DIR / ".env")

DATABASES = {
"default": {
        "ENGINE": "django.db.backends.postgresql",
        "NAME": os.getenv("POSTGRES_DB", "database"),
        "USER": os.getenv("POSTGRES_USER", "user"),
        "PASSWORD": os.getenv("POSTGRES_PASSWORD", "password"),
        "HOST": os.getenv("POSTGRES_HOST", "db"),
        "PORT": os.getenv("POSTGRES_PORT", "5432"),
    }
}

--- .env

POSTGRES_DB=database
POSTGRES_USER=user
POSTGRES_PASSWORD=password
POSTGRES_HOST=db
POSTGRES_PORT=5432
    """


def set_script():
    """
myapp/management/commands/startbot.py

--- startbot.py

from django.core.management.base import BaseCommand
from django.conf import settings

def start():
    print('start hello!')

class Command(BaseCommand):
    help = "Запуск Telegram-бота"

    def handle(self, *args, **kwargs):
        start()

--- command

python manage.py startbot
    """

